<template>
    <div>
        <div v-if="hasVariants" class="variations-container">
            <div class="size-variation">
                <h5>Talles</h5>
                <select v-model="selectedVariantId" class="form-select form-select-lg mb-3">
                    <option :value="null">--</option>
                    <option v-for="variant in product.variants" :key="variant.id" :value="variant.id">
                        {{ variant.size ? variant.size.name : variant.name }}
                    </option>
                </select>
                <p v-if="selectedVariantDescription" class="variant-description">
                    {{ selectedVariantDescription }}
                </p>
            </div>
        </div>
        <div v-if="selectedVariantId" class="stock-container">
            <h5>{{ stockMessage }}</h5>
        </div>
        <div class="buttons-container">
            <button class="buy-now" :disabled="!isStockAvailable" @click="buyNow">COMPRAR AHORA</button>
            <button class="add-to-cart" :disabled="!isStockAvailable" @click="addToCart">AGREGAR AL CARRITO</button>
        </div>
    </div>
</template>

<script setup>
import { cartStore } from "../../js/stores/cart.js";
import { ref, computed } from "vue";

const props = defineProps({
    product: {
        type: Object,
        required: true,
    },
});

const store = cartStore();
const selectedVariantId = ref(null);

// Check if the product has variants
const hasVariants = computed(() => {
    return props.product.variants && props.product.variants.length > 0;
});

// Compute the stock availability based on the selected variant
const isStockAvailable = computed(() => {
    const stock = hasVariants.value
        ? props.product.variants.find((variant) => variant.id === selectedVariantId.value)?.stock || 0
        : props.product.stock;
    return stock > 0;
});

// Compute stock message based on availability
const stockMessage = computed(() => {
    return isStockAvailable.value ? "Stock Disponible" : "Sin Stock";
});

function addToCart() {
    const productToAdd = {
        id: props.product.id,
        sku: props.product.sku,
        name: props.product.name,
        price: props.product.price,
        image: props.product.image,
        variantId: selectedVariantId.value, // Asegúrate de pasar el ID de la variante seleccionada
        variant: props.product.variants.find((variant) => variant.id === selectedVariantId.value)?.name || "", // Asegúrate de pasar el ID de la variante seleccionada
        variantSku: props.product.variants.find((variant) => variant.id === selectedVariantId.value)?.sku || "", // Asegúrate de pasar el ID de la variante seleccionada
    };
    store.addItem(productToAdd);

    if (process.env.MARKETING_TOOLS_ENABLED) {
        // try {
        trackEvent(productToAdd);
        // } catch () {
        // }
    }

    store.toggleSideCart();
}

function trackEvent(productToAdd) {
    let contentId = productToAdd.variantSku ? productToAdd.variantSku : productToAdd.sku;

    let customData = {
        content_name: productToAdd.name,
        content_ids: [contentId],
        content_type: "product",
        value: productToAdd.price,
        currency: "ARS",
        quantity: 1,
    };

    // Generar ID de evento aleatorio
    const eventId = "ev_" + Math.random().toString(36).substring(2, 15) + Math.random().toString(36).substring(2, 15);

    // Evento para el Pixel de Meta (browser-side)
    if (typeof fbq !== "undefined") {
        fbq("track", "AddToCart", customData, { eventID: eventId });
    }

    // Datos para la Conversions API (server-side)
    const serverData = {
        eventName: "AddToCart",
        eventId: eventId,
        customData: {
            ...customData,
        },
        actionSource: "website",
    };

    // Enviar datos al servidor para la Conversions API
    fetch("/integration/meta/event", {
        method: "POST",
        headers: {
            "Content-Type": "application/json",
        },
        body: JSON.stringify(serverData),
    })
        .then((response) => response.json())
        .catch((error) => {
            console.error("Error on Conversions API:", error);
        });

    dataLayer.push({ ecommerce: null }); // Clear the previous ecommerce object.
    dataLayer.push({
        event: "add_to_cart",
        ecommerce: {
            currency: "ARS",
            value: parseFloat(productToAdd.price),
            items: [
                {
                    item_id: contentId,
                    item_name: productToAdd.name,
                    quantity: 1,
                },
            ],
        },
    });
}

function buyNow() {
    const productToAdd = {
        id: props.product.id,
        sku: props.product.sku,
        name: props.product.name,
        price: props.product.price,
        image: props.product.image,
        variantId: selectedVariantId.value, // Asegúrate de pasar el ID de la variante seleccionada
        variant: props.product.variants.find((variant) => variant.id === selectedVariantId.value)?.name || "", // Asegúrate de pasar el ID de la variante seleccionada
        variantSku: props.product.variants.find((variant) => variant.id === selectedVariantId.value)?.sku || "", // Asegúrate de pasar el ID de la variante seleccionada
    };

    store.addItem(productToAdd); // Agrega el producto al carrito

    if (process.env.MARKETING_TOOLS_ENABLED) {
        trackEvent(productToAdd);
    }

    setTimeout(() => {
        window.location = "/carrito";
    }, 1000);
}

const selectedVariantDescription = computed(() => {
    const variant = props.product.variants.find((v) => v.id === selectedVariantId.value);
    return variant?.description || "";
});
</script>

<style lang="scss" scoped>
@use "../../scss/variables" as vars;
</style>
